import { MetadataBearer as $MetadataBearer, SmithyException as __SmithyException } from "@aws-sdk/types";

export interface AddTagsToStreamInput {
    
    StreamName: string | undefined;
    
    Tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace AddTagsToStreamInput {
    
    const filterSensitiveLog: (obj: AddTagsToStreamInput) => any;
}

export interface InvalidArgumentException extends __SmithyException, $MetadataBearer {
    name: "InvalidArgumentException";
    $fault: "client";
    
    message?: string;
}
export declare namespace InvalidArgumentException {
    
    const filterSensitiveLog: (obj: InvalidArgumentException) => any;
}

export interface LimitExceededException extends __SmithyException, $MetadataBearer {
    name: "LimitExceededException";
    $fault: "client";
    
    message?: string;
}
export declare namespace LimitExceededException {
    
    const filterSensitiveLog: (obj: LimitExceededException) => any;
}

export interface ResourceInUseException extends __SmithyException, $MetadataBearer {
    name: "ResourceInUseException";
    $fault: "client";
    
    message?: string;
}
export declare namespace ResourceInUseException {
    
    const filterSensitiveLog: (obj: ResourceInUseException) => any;
}

export interface ResourceNotFoundException extends __SmithyException, $MetadataBearer {
    name: "ResourceNotFoundException";
    $fault: "client";
    
    message?: string;
}
export declare namespace ResourceNotFoundException {
    
    const filterSensitiveLog: (obj: ResourceNotFoundException) => any;
}

export interface HashKeyRange {
    
    StartingHashKey: string | undefined;
    
    EndingHashKey: string | undefined;
}
export declare namespace HashKeyRange {
    
    const filterSensitiveLog: (obj: HashKeyRange) => any;
}

export interface ChildShard {
    
    ShardId: string | undefined;
    
    ParentShards: string[] | undefined;
    
    HashKeyRange: HashKeyRange | undefined;
}
export declare namespace ChildShard {
    
    const filterSensitiveLog: (obj: ChildShard) => any;
}
export declare enum ConsumerStatus {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING"
}

export interface Consumer {
    
    ConsumerName: string | undefined;
    
    ConsumerARN: string | undefined;
    
    ConsumerStatus: ConsumerStatus | string | undefined;
    
    ConsumerCreationTimestamp: Date | undefined;
}
export declare namespace Consumer {
    
    const filterSensitiveLog: (obj: Consumer) => any;
}

export interface ConsumerDescription {
    
    ConsumerName: string | undefined;
    
    ConsumerARN: string | undefined;
    
    ConsumerStatus: ConsumerStatus | string | undefined;
    
    ConsumerCreationTimestamp: Date | undefined;
    
    StreamARN: string | undefined;
}
export declare namespace ConsumerDescription {
    
    const filterSensitiveLog: (obj: ConsumerDescription) => any;
}
export declare enum StreamMode {
    ON_DEMAND = "ON_DEMAND",
    PROVISIONED = "PROVISIONED"
}

export interface StreamModeDetails {
    
    StreamMode: StreamMode | string | undefined;
}
export declare namespace StreamModeDetails {
    
    const filterSensitiveLog: (obj: StreamModeDetails) => any;
}

export interface CreateStreamInput {
    
    StreamName: string | undefined;
    
    ShardCount?: number;
    
    StreamModeDetails?: StreamModeDetails;
}
export declare namespace CreateStreamInput {
    
    const filterSensitiveLog: (obj: CreateStreamInput) => any;
}

export interface DecreaseStreamRetentionPeriodInput {
    
    StreamName: string | undefined;
    
    RetentionPeriodHours: number | undefined;
}
export declare namespace DecreaseStreamRetentionPeriodInput {
    
    const filterSensitiveLog: (obj: DecreaseStreamRetentionPeriodInput) => any;
}

export interface DeleteStreamInput {
    
    StreamName: string | undefined;
    
    EnforceConsumerDeletion?: boolean;
}
export declare namespace DeleteStreamInput {
    
    const filterSensitiveLog: (obj: DeleteStreamInput) => any;
}
export interface DeregisterStreamConsumerInput {
    
    StreamARN?: string;
    
    ConsumerName?: string;
    
    ConsumerARN?: string;
}
export declare namespace DeregisterStreamConsumerInput {
    
    const filterSensitiveLog: (obj: DeregisterStreamConsumerInput) => any;
}
export interface DescribeLimitsInput {
}
export declare namespace DescribeLimitsInput {
    
    const filterSensitiveLog: (obj: DescribeLimitsInput) => any;
}
export interface DescribeLimitsOutput {
    
    ShardLimit: number | undefined;
    
    OpenShardCount: number | undefined;
    
    OnDemandStreamCount: number | undefined;
    
    OnDemandStreamCountLimit: number | undefined;
}
export declare namespace DescribeLimitsOutput {
    
    const filterSensitiveLog: (obj: DescribeLimitsOutput) => any;
}

export interface DescribeStreamInput {
    
    StreamName: string | undefined;
    
    Limit?: number;
    
    ExclusiveStartShardId?: string;
}
export declare namespace DescribeStreamInput {
    
    const filterSensitiveLog: (obj: DescribeStreamInput) => any;
}
export declare enum EncryptionType {
    KMS = "KMS",
    NONE = "NONE"
}
export declare enum MetricsName {
    ALL = "ALL",
    INCOMING_BYTES = "IncomingBytes",
    INCOMING_RECORDS = "IncomingRecords",
    ITERATOR_AGE_MILLISECONDS = "IteratorAgeMilliseconds",
    OUTGOING_BYTES = "OutgoingBytes",
    OUTGOING_RECORDS = "OutgoingRecords",
    READ_PROVISIONED_THROUGHPUT_EXCEEDED = "ReadProvisionedThroughputExceeded",
    WRITE_PROVISIONED_THROUGHPUT_EXCEEDED = "WriteProvisionedThroughputExceeded"
}

export interface EnhancedMetrics {
    
    ShardLevelMetrics?: (MetricsName | string)[];
}
export declare namespace EnhancedMetrics {
    
    const filterSensitiveLog: (obj: EnhancedMetrics) => any;
}

export interface SequenceNumberRange {
    
    StartingSequenceNumber: string | undefined;
    
    EndingSequenceNumber?: string;
}
export declare namespace SequenceNumberRange {
    
    const filterSensitiveLog: (obj: SequenceNumberRange) => any;
}

export interface Shard {
    
    ShardId: string | undefined;
    
    ParentShardId?: string;
    
    AdjacentParentShardId?: string;
    
    HashKeyRange: HashKeyRange | undefined;
    
    SequenceNumberRange: SequenceNumberRange | undefined;
}
export declare namespace Shard {
    
    const filterSensitiveLog: (obj: Shard) => any;
}
export declare enum StreamStatus {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    UPDATING = "UPDATING"
}

export interface StreamDescription {
    
    StreamName: string | undefined;
    
    StreamARN: string | undefined;
    
    StreamStatus: StreamStatus | string | undefined;
    
    StreamModeDetails?: StreamModeDetails;
    
    Shards: Shard[] | undefined;
    
    HasMoreShards: boolean | undefined;
    
    RetentionPeriodHours: number | undefined;
    
    StreamCreationTimestamp: Date | undefined;
    
    EnhancedMonitoring: EnhancedMetrics[] | undefined;
    
    EncryptionType?: EncryptionType | string;
    
    KeyId?: string;
}
export declare namespace StreamDescription {
    
    const filterSensitiveLog: (obj: StreamDescription) => any;
}

export interface DescribeStreamOutput {
    
    StreamDescription: StreamDescription | undefined;
}
export declare namespace DescribeStreamOutput {
    
    const filterSensitiveLog: (obj: DescribeStreamOutput) => any;
}
export interface DescribeStreamConsumerInput {
    
    StreamARN?: string;
    
    ConsumerName?: string;
    
    ConsumerARN?: string;
}
export declare namespace DescribeStreamConsumerInput {
    
    const filterSensitiveLog: (obj: DescribeStreamConsumerInput) => any;
}
export interface DescribeStreamConsumerOutput {
    
    ConsumerDescription: ConsumerDescription | undefined;
}
export declare namespace DescribeStreamConsumerOutput {
    
    const filterSensitiveLog: (obj: DescribeStreamConsumerOutput) => any;
}
export interface DescribeStreamSummaryInput {
    
    StreamName: string | undefined;
}
export declare namespace DescribeStreamSummaryInput {
    
    const filterSensitiveLog: (obj: DescribeStreamSummaryInput) => any;
}

export interface StreamDescriptionSummary {
    
    StreamName: string | undefined;
    
    StreamARN: string | undefined;
    
    StreamStatus: StreamStatus | string | undefined;
    
    StreamModeDetails?: StreamModeDetails;
    
    RetentionPeriodHours: number | undefined;
    
    StreamCreationTimestamp: Date | undefined;
    
    EnhancedMonitoring: EnhancedMetrics[] | undefined;
    
    EncryptionType?: EncryptionType | string;
    
    KeyId?: string;
    
    OpenShardCount: number | undefined;
    
    ConsumerCount?: number;
}
export declare namespace StreamDescriptionSummary {
    
    const filterSensitiveLog: (obj: StreamDescriptionSummary) => any;
}
export interface DescribeStreamSummaryOutput {
    
    StreamDescriptionSummary: StreamDescriptionSummary | undefined;
}
export declare namespace DescribeStreamSummaryOutput {
    
    const filterSensitiveLog: (obj: DescribeStreamSummaryOutput) => any;
}

export interface DisableEnhancedMonitoringInput {
    
    StreamName: string | undefined;
    
    ShardLevelMetrics: (MetricsName | string)[] | undefined;
}
export declare namespace DisableEnhancedMonitoringInput {
    
    const filterSensitiveLog: (obj: DisableEnhancedMonitoringInput) => any;
}

export interface EnhancedMonitoringOutput {
    
    StreamName?: string;
    
    CurrentShardLevelMetrics?: (MetricsName | string)[];
    
    DesiredShardLevelMetrics?: (MetricsName | string)[];
}
export declare namespace EnhancedMonitoringOutput {
    
    const filterSensitiveLog: (obj: EnhancedMonitoringOutput) => any;
}

export interface EnableEnhancedMonitoringInput {
    
    StreamName: string | undefined;
    
    ShardLevelMetrics: (MetricsName | string)[] | undefined;
}
export declare namespace EnableEnhancedMonitoringInput {
    
    const filterSensitiveLog: (obj: EnableEnhancedMonitoringInput) => any;
}

export interface ExpiredIteratorException extends __SmithyException, $MetadataBearer {
    name: "ExpiredIteratorException";
    $fault: "client";
    
    message?: string;
}
export declare namespace ExpiredIteratorException {
    
    const filterSensitiveLog: (obj: ExpiredIteratorException) => any;
}

export interface ExpiredNextTokenException extends __SmithyException, $MetadataBearer {
    name: "ExpiredNextTokenException";
    $fault: "client";
    message?: string;
}
export declare namespace ExpiredNextTokenException {
    
    const filterSensitiveLog: (obj: ExpiredNextTokenException) => any;
}

export interface GetRecordsInput {
    
    ShardIterator: string | undefined;
    
    Limit?: number;
}
export declare namespace GetRecordsInput {
    
    const filterSensitiveLog: (obj: GetRecordsInput) => any;
}

export interface _Record {
    
    SequenceNumber: string | undefined;
    
    ApproximateArrivalTimestamp?: Date;
    
    Data: Uint8Array | undefined;
    
    PartitionKey: string | undefined;
    
    EncryptionType?: EncryptionType | string;
}
export declare namespace _Record {
    
    const filterSensitiveLog: (obj: _Record) => any;
}

export interface GetRecordsOutput {
    
    Records: _Record[] | undefined;
    
    NextShardIterator?: string;
    
    MillisBehindLatest?: number;
    
    ChildShards?: ChildShard[];
}
export declare namespace GetRecordsOutput {
    
    const filterSensitiveLog: (obj: GetRecordsOutput) => any;
}

export interface KMSAccessDeniedException extends __SmithyException, $MetadataBearer {
    name: "KMSAccessDeniedException";
    $fault: "client";
    
    message?: string;
}
export declare namespace KMSAccessDeniedException {
    
    const filterSensitiveLog: (obj: KMSAccessDeniedException) => any;
}

export interface KMSDisabledException extends __SmithyException, $MetadataBearer {
    name: "KMSDisabledException";
    $fault: "client";
    
    message?: string;
}
export declare namespace KMSDisabledException {
    
    const filterSensitiveLog: (obj: KMSDisabledException) => any;
}

export interface KMSInvalidStateException extends __SmithyException, $MetadataBearer {
    name: "KMSInvalidStateException";
    $fault: "client";
    
    message?: string;
}
export declare namespace KMSInvalidStateException {
    
    const filterSensitiveLog: (obj: KMSInvalidStateException) => any;
}

export interface KMSNotFoundException extends __SmithyException, $MetadataBearer {
    name: "KMSNotFoundException";
    $fault: "client";
    
    message?: string;
}
export declare namespace KMSNotFoundException {
    
    const filterSensitiveLog: (obj: KMSNotFoundException) => any;
}

export interface KMSOptInRequired extends __SmithyException, $MetadataBearer {
    name: "KMSOptInRequired";
    $fault: "client";
    
    message?: string;
}
export declare namespace KMSOptInRequired {
    
    const filterSensitiveLog: (obj: KMSOptInRequired) => any;
}

export interface KMSThrottlingException extends __SmithyException, $MetadataBearer {
    name: "KMSThrottlingException";
    $fault: "client";
    
    message?: string;
}
export declare namespace KMSThrottlingException {
    
    const filterSensitiveLog: (obj: KMSThrottlingException) => any;
}

export interface ProvisionedThroughputExceededException extends __SmithyException, $MetadataBearer {
    name: "ProvisionedThroughputExceededException";
    $fault: "client";
    
    message?: string;
}
export declare namespace ProvisionedThroughputExceededException {
    
    const filterSensitiveLog: (obj: ProvisionedThroughputExceededException) => any;
}
export declare enum ShardIteratorType {
    AFTER_SEQUENCE_NUMBER = "AFTER_SEQUENCE_NUMBER",
    AT_SEQUENCE_NUMBER = "AT_SEQUENCE_NUMBER",
    AT_TIMESTAMP = "AT_TIMESTAMP",
    LATEST = "LATEST",
    TRIM_HORIZON = "TRIM_HORIZON"
}

export interface GetShardIteratorInput {
    
    StreamName: string | undefined;
    
    ShardId: string | undefined;
    
    ShardIteratorType: ShardIteratorType | string | undefined;
    
    StartingSequenceNumber?: string;
    
    Timestamp?: Date;
}
export declare namespace GetShardIteratorInput {
    
    const filterSensitiveLog: (obj: GetShardIteratorInput) => any;
}

export interface GetShardIteratorOutput {
    
    ShardIterator?: string;
}
export declare namespace GetShardIteratorOutput {
    
    const filterSensitiveLog: (obj: GetShardIteratorOutput) => any;
}

export interface IncreaseStreamRetentionPeriodInput {
    
    StreamName: string | undefined;
    
    RetentionPeriodHours: number | undefined;
}
export declare namespace IncreaseStreamRetentionPeriodInput {
    
    const filterSensitiveLog: (obj: IncreaseStreamRetentionPeriodInput) => any;
}

export interface InternalFailureException extends __SmithyException {
    name: "InternalFailureException";
    $fault: "server";
    message?: string;
}
export declare namespace InternalFailureException {
    
    const filterSensitiveLog: (obj: InternalFailureException) => any;
}
export declare enum ShardFilterType {
    AFTER_SHARD_ID = "AFTER_SHARD_ID",
    AT_LATEST = "AT_LATEST",
    AT_TIMESTAMP = "AT_TIMESTAMP",
    AT_TRIM_HORIZON = "AT_TRIM_HORIZON",
    FROM_TIMESTAMP = "FROM_TIMESTAMP",
    FROM_TRIM_HORIZON = "FROM_TRIM_HORIZON"
}

export interface ShardFilter {
    
    Type: ShardFilterType | string | undefined;
    
    ShardId?: string;
    
    Timestamp?: Date;
}
export declare namespace ShardFilter {
    
    const filterSensitiveLog: (obj: ShardFilter) => any;
}
export interface ListShardsInput {
    
    StreamName?: string;
    
    NextToken?: string;
    
    ExclusiveStartShardId?: string;
    
    MaxResults?: number;
    
    StreamCreationTimestamp?: Date;
    
    ShardFilter?: ShardFilter;
}
export declare namespace ListShardsInput {
    
    const filterSensitiveLog: (obj: ListShardsInput) => any;
}
export interface ListShardsOutput {
    
    Shards?: Shard[];
    
    NextToken?: string;
}
export declare namespace ListShardsOutput {
    
    const filterSensitiveLog: (obj: ListShardsOutput) => any;
}
export interface ListStreamConsumersInput {
    
    StreamARN: string | undefined;
    
    NextToken?: string;
    
    MaxResults?: number;
    
    StreamCreationTimestamp?: Date;
}
export declare namespace ListStreamConsumersInput {
    
    const filterSensitiveLog: (obj: ListStreamConsumersInput) => any;
}
export interface ListStreamConsumersOutput {
    
    Consumers?: Consumer[];
    
    NextToken?: string;
}
export declare namespace ListStreamConsumersOutput {
    
    const filterSensitiveLog: (obj: ListStreamConsumersOutput) => any;
}

export interface ListStreamsInput {
    
    Limit?: number;
    
    ExclusiveStartStreamName?: string;
}
export declare namespace ListStreamsInput {
    
    const filterSensitiveLog: (obj: ListStreamsInput) => any;
}

export interface ListStreamsOutput {
    
    StreamNames: string[] | undefined;
    
    HasMoreStreams: boolean | undefined;
}
export declare namespace ListStreamsOutput {
    
    const filterSensitiveLog: (obj: ListStreamsOutput) => any;
}

export interface ListTagsForStreamInput {
    
    StreamName: string | undefined;
    
    ExclusiveStartTagKey?: string;
    
    Limit?: number;
}
export declare namespace ListTagsForStreamInput {
    
    const filterSensitiveLog: (obj: ListTagsForStreamInput) => any;
}

export interface Tag {
    
    Key: string | undefined;
    
    Value?: string;
}
export declare namespace Tag {
    
    const filterSensitiveLog: (obj: Tag) => any;
}

export interface ListTagsForStreamOutput {
    
    Tags: Tag[] | undefined;
    
    HasMoreTags: boolean | undefined;
}
export declare namespace ListTagsForStreamOutput {
    
    const filterSensitiveLog: (obj: ListTagsForStreamOutput) => any;
}

export interface MergeShardsInput {
    
    StreamName: string | undefined;
    
    ShardToMerge: string | undefined;
    
    AdjacentShardToMerge: string | undefined;
}
export declare namespace MergeShardsInput {
    
    const filterSensitiveLog: (obj: MergeShardsInput) => any;
}

export interface ValidationException extends __SmithyException, $MetadataBearer {
    name: "ValidationException";
    $fault: "client";
    message?: string;
}
export declare namespace ValidationException {
    
    const filterSensitiveLog: (obj: ValidationException) => any;
}

export interface PutRecordInput {
    
    StreamName: string | undefined;
    
    Data: Uint8Array | undefined;
    
    PartitionKey: string | undefined;
    
    ExplicitHashKey?: string;
    
    SequenceNumberForOrdering?: string;
}
export declare namespace PutRecordInput {
    
    const filterSensitiveLog: (obj: PutRecordInput) => any;
}

export interface PutRecordOutput {
    
    ShardId: string | undefined;
    
    SequenceNumber: string | undefined;
    
    EncryptionType?: EncryptionType | string;
}
export declare namespace PutRecordOutput {
    
    const filterSensitiveLog: (obj: PutRecordOutput) => any;
}

export interface PutRecordsRequestEntry {
    
    Data: Uint8Array | undefined;
    
    ExplicitHashKey?: string;
    
    PartitionKey: string | undefined;
}
export declare namespace PutRecordsRequestEntry {
    
    const filterSensitiveLog: (obj: PutRecordsRequestEntry) => any;
}

export interface PutRecordsInput {
    
    Records: PutRecordsRequestEntry[] | undefined;
    
    StreamName: string | undefined;
}
export declare namespace PutRecordsInput {
    
    const filterSensitiveLog: (obj: PutRecordsInput) => any;
}

export interface PutRecordsResultEntry {
    
    SequenceNumber?: string;
    
    ShardId?: string;
    
    ErrorCode?: string;
    
    ErrorMessage?: string;
}
export declare namespace PutRecordsResultEntry {
    
    const filterSensitiveLog: (obj: PutRecordsResultEntry) => any;
}

export interface PutRecordsOutput {
    
    FailedRecordCount?: number;
    
    Records: PutRecordsResultEntry[] | undefined;
    
    EncryptionType?: EncryptionType | string;
}
export declare namespace PutRecordsOutput {
    
    const filterSensitiveLog: (obj: PutRecordsOutput) => any;
}
export interface RegisterStreamConsumerInput {
    
    StreamARN: string | undefined;
    
    ConsumerName: string | undefined;
}
export declare namespace RegisterStreamConsumerInput {
    
    const filterSensitiveLog: (obj: RegisterStreamConsumerInput) => any;
}
export interface RegisterStreamConsumerOutput {
    
    Consumer: Consumer | undefined;
}
export declare namespace RegisterStreamConsumerOutput {
    
    const filterSensitiveLog: (obj: RegisterStreamConsumerOutput) => any;
}

export interface RemoveTagsFromStreamInput {
    
    StreamName: string | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace RemoveTagsFromStreamInput {
    
    const filterSensitiveLog: (obj: RemoveTagsFromStreamInput) => any;
}

export interface SplitShardInput {
    
    StreamName: string | undefined;
    
    ShardToSplit: string | undefined;
    
    NewStartingHashKey: string | undefined;
}
export declare namespace SplitShardInput {
    
    const filterSensitiveLog: (obj: SplitShardInput) => any;
}
export interface StartStreamEncryptionInput {
    
    StreamName: string | undefined;
    
    EncryptionType: EncryptionType | string | undefined;
    
    KeyId: string | undefined;
}
export declare namespace StartStreamEncryptionInput {
    
    const filterSensitiveLog: (obj: StartStreamEncryptionInput) => any;
}
export interface StopStreamEncryptionInput {
    
    StreamName: string | undefined;
    
    EncryptionType: EncryptionType | string | undefined;
    
    KeyId: string | undefined;
}
export declare namespace StopStreamEncryptionInput {
    
    const filterSensitiveLog: (obj: StopStreamEncryptionInput) => any;
}

export interface StartingPosition {
    
    Type: ShardIteratorType | string | undefined;
    
    SequenceNumber?: string;
    
    Timestamp?: Date;
}
export declare namespace StartingPosition {
    
    const filterSensitiveLog: (obj: StartingPosition) => any;
}
export interface SubscribeToShardInput {
    
    ConsumerARN: string | undefined;
    
    ShardId: string | undefined;
    
    StartingPosition: StartingPosition | undefined;
}
export declare namespace SubscribeToShardInput {
    
    const filterSensitiveLog: (obj: SubscribeToShardInput) => any;
}

export interface SubscribeToShardEvent {
    
    Records: _Record[] | undefined;
    
    ContinuationSequenceNumber: string | undefined;
    
    MillisBehindLatest: number | undefined;
    
    ChildShards?: ChildShard[];
}
export declare namespace SubscribeToShardEvent {
    
    const filterSensitiveLog: (obj: SubscribeToShardEvent) => any;
}

export declare type SubscribeToShardEventStream = SubscribeToShardEventStream.InternalFailureExceptionMember | SubscribeToShardEventStream.KMSAccessDeniedExceptionMember | SubscribeToShardEventStream.KMSDisabledExceptionMember | SubscribeToShardEventStream.KMSInvalidStateExceptionMember | SubscribeToShardEventStream.KMSNotFoundExceptionMember | SubscribeToShardEventStream.KMSOptInRequiredMember | SubscribeToShardEventStream.KMSThrottlingExceptionMember | SubscribeToShardEventStream.ResourceInUseExceptionMember | SubscribeToShardEventStream.ResourceNotFoundExceptionMember | SubscribeToShardEventStream.SubscribeToShardEventMember | SubscribeToShardEventStream.$UnknownMember;
export declare namespace SubscribeToShardEventStream {
    
    interface SubscribeToShardEventMember {
        SubscribeToShardEvent: SubscribeToShardEvent;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface ResourceNotFoundExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException: ResourceNotFoundException;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface ResourceInUseExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException: ResourceInUseException;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface KMSDisabledExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException: KMSDisabledException;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface KMSInvalidStateExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException: KMSInvalidStateException;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface KMSAccessDeniedExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException: KMSAccessDeniedException;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface KMSNotFoundExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException: KMSNotFoundException;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface KMSOptInRequiredMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired: KMSOptInRequired;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface KMSThrottlingExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException: KMSThrottlingException;
        InternalFailureException?: never;
        $unknown?: never;
    }
    
    interface InternalFailureExceptionMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException: InternalFailureException;
        $unknown?: never;
    }
    interface $UnknownMember {
        SubscribeToShardEvent?: never;
        ResourceNotFoundException?: never;
        ResourceInUseException?: never;
        KMSDisabledException?: never;
        KMSInvalidStateException?: never;
        KMSAccessDeniedException?: never;
        KMSNotFoundException?: never;
        KMSOptInRequired?: never;
        KMSThrottlingException?: never;
        InternalFailureException?: never;
        $unknown: [
            string,
            any
        ];
    }
    interface Visitor<T> {
        SubscribeToShardEvent: (value: SubscribeToShardEvent) => T;
        ResourceNotFoundException: (value: ResourceNotFoundException) => T;
        ResourceInUseException: (value: ResourceInUseException) => T;
        KMSDisabledException: (value: KMSDisabledException) => T;
        KMSInvalidStateException: (value: KMSInvalidStateException) => T;
        KMSAccessDeniedException: (value: KMSAccessDeniedException) => T;
        KMSNotFoundException: (value: KMSNotFoundException) => T;
        KMSOptInRequired: (value: KMSOptInRequired) => T;
        KMSThrottlingException: (value: KMSThrottlingException) => T;
        InternalFailureException: (value: InternalFailureException) => T;
        _: (name: string, value: any) => T;
    }
    const visit: <T>(value: SubscribeToShardEventStream, visitor: Visitor<T>) => T;
    
    const filterSensitiveLog: (obj: SubscribeToShardEventStream) => any;
}
export interface SubscribeToShardOutput {
    
    EventStream: AsyncIterable<SubscribeToShardEventStream> | undefined;
}
export declare namespace SubscribeToShardOutput {
    
    const filterSensitiveLog: (obj: SubscribeToShardOutput) => any;
}
export declare enum ScalingType {
    UNIFORM_SCALING = "UNIFORM_SCALING"
}
export interface UpdateShardCountInput {
    
    StreamName: string | undefined;
    
    TargetShardCount: number | undefined;
    
    ScalingType: ScalingType | string | undefined;
}
export declare namespace UpdateShardCountInput {
    
    const filterSensitiveLog: (obj: UpdateShardCountInput) => any;
}
export interface UpdateShardCountOutput {
    
    StreamName?: string;
    
    CurrentShardCount?: number;
    
    TargetShardCount?: number;
}
export declare namespace UpdateShardCountOutput {
    
    const filterSensitiveLog: (obj: UpdateShardCountOutput) => any;
}
export interface UpdateStreamModeInput {
    
    StreamARN: string | undefined;
    
    StreamModeDetails: StreamModeDetails | undefined;
}
export declare namespace UpdateStreamModeInput {
    
    const filterSensitiveLog: (obj: UpdateStreamModeInput) => any;
}
