"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ignoredNodeModules = void 0;
exports.isBlackListedModule = isBlackListedModule;

function isBlackListedModule(filename) {
  if (filename.startsWith('native ')) {
    return true;
  } // Ignoring AWS Lambda's runtime modules


  if (filename.startsWith('/var/runtime/')) {
    return true;
  }

  let match = filename.match(/\/node_modules\/(.*?)\//);

  if (null == match || match.length === 0) {
    return false;
  }

  let whitelistedModules = process.env.ROOKOUT_WHITELIST_MODULES;

  if (whitelistedModules !== undefined) {
    for (let whitelistedModule of whitelistedModules.replace(/['"]/g, '').split(';')) {
      if (whitelistedModule === match[1]) {
        return false;
      }
    }
  }

  if (ignoredNodeModules.has(match[1])) {
    return true;
  }

  return false;
}

const ignoredNodeModules = new Set(["is-redirect", "gulp-minify-css", "strip-bom", "d3-chord", "magic-string", "lodash.isempty", "@material-ui", "limiter", "postcss-normalize-url", "jmespath", "jwt-simple", "yeoman-environment", "mongoose-legacy-pluralize", "vfile", "koa-convert", "is-retry-allowed", "opener", "url-join", "filesize", "ansi-bgmagenta", "spark-md5", "d3-axis", "babel-plugin-transform-export-extensions", "path-platform", "helmet-crossdomain", "ember-cli-babel", "@mrmlnc", "webpack-bundle-analyzer", "postcss-reporter", "bmp-js", "public-encrypt", "ioredis", "username-sync", "koa-body", "randombytes", "aproba", "lodash.clonedeep", "globule", "babel-plugin-transform-react-display-name", "mathml-tag-names", "buffer-equal-constant-time", "listr-verbose-renderer", "ordered-read-streams", "has-flag", "url-to-options", "envinfo", "execall", "fast-future", "buffer-crc32", "minstache", "koa-mount", "node-pre-gyp", "source-map-support", "wreck", "unyield", "dev-ip", "babel-helper-function-name", "numeral", "xmlcreate", "object-visit", "sparse-bitfield", "dom-helpers", "through2", "async-each", "connect-redis", "gzip-size", "mem", "babel-polyfill", "jasmine", "eventlistener", "rc-util", "react-lifecycles-compat", "merge-deep", "lodash.memoize", "path", "passport-oauth1", "postcss-import", "interpret", "streamsearch", "get-assigned-identifiers", "decompress-targz", "detect-newline", "imagemin-pngquant", "sort-keys-length", "is-finite", "ember-cli-htmlbars", "friendly-errors-webpack-plugin", "component-classes", "vinyl", "@szmarczak", "babel-register", "fast-decode-uri-component", "stackframe", "lodash.isnumber", "sliced", "set-value", "is-observable", "expand-braces", "single-line-log", "ansi-magenta", "ssh2-streams", "prismjs", "app-root-path", "uniq", "postcss-markdown", "date-fns", "bs58", "blank-object", "babel-plugin-transform-es2015-shorthand-properties", "terser-webpack-plugin", "fstream", "sw-precache-webpack-plugin", "prelude-ls", "webpack", "listr-silent-renderer", "passport", "ip", "file-exists", "react-clone-referenced-element", "cli-cursor", "winston-compat", "@sindresorhus", "lodash._escapehtmlchar", "url-loader", "binary", "streamroller", "har-validator", "url-parse", "ware", "standard-as-callback", "gulp-autoprefixer", "regex-cache", "stream-http", "remove-bom-buffer", "react-addons-css-transition-group", "taskgroup", "bin-build", "xhr", "p-locate", "rc-align", "ms", "deprecated", "hoist-non-react-statics", "run-sequence", "mz", "jws", "path-parse", "fast-levenshtein", "xml2json", "sync-exec", "ethjs-unit", "postcss-env-function", "spdx-correct", "tfunk", "tweetnacl", "sqlstring", "plist", "absolute", "d3-fetch", "js-sha3", "d3-quadtree", "html-entities", "rechoir", "machine", "ent", "react-select", "grunt-contrib-clean", "requizzle", "config", "w3c-xmlserializer", "import-fresh", "localtunnel", "karma-coverage", "esutils", "nwsapi", "after", "fs-readdir-recursive", "window-size", "react-deep-force-update", "ansi-gray", "first-chunk-stream", "sparkles", "arch", "yargs-parser", "continuation-local-storage", "globby", "rcfinder", "bootstrap", "jsonparse", "scryptsy", "lodash.defaults", "js2xmlparser", "lazy-cache", "redent", "buffer-more-ints", "eslint-plugin-flowtype", "is-number-object", "case-sensitive-paths-webpack-plugin", "over", "vary", "is-absolute-url", "awesome-typescript-loader", "imports-loader", "section-matter", "is-hex-prefixed", "parse-passwd", "underscore-contrib", "@types", "flagged-respawn", "tar-fs", "hasha", "cli", "nocache", "httpntlm", "dns-txt", "regexpp", "lodash.once", "http-proxy-agent", "gulp-htmlmin", "gulp-shell", "command-line-args", "arr-union", "rfdc", "pretty-error", "typescript", "readable-stream", "lodash.isinteger", "p-try", "broccoli-merge-trees", "nodemon", "constant-case", "regex-not", "spdx-exceptions", "deep-defaults", "invert-kv", "unzip-response", "querystring-es3", "source-map-loader", "deps-sort", "postcss-dir-pseudo-class", "hex-color-regex", "socket.io-adapter", "react-router-dom", "is-number", "lcid", "aria-query", "gulp-clean-css", "loader-utils", "pug-linker", "babel-helper-explode-class", "consolidate", "pngjs", "leveldown", "map-age-cleaner", "obuf", "striptags", "path-case", "babel-plugin-transform-es2015-function-name", "mqtt-packet", "commist", "fb-watchman", "lodash._isiterateecall", "long-timeout", "rw", "os-locale", "xml-crypto", "natural-compare", "graphql-tag", "rev-hash", "postcss-normalize-positions", "v8-compile-cache", "rx", "bs-recipes", "jss-vendor-prefixer", "p-event", "js-git", "sprintf", "dotenv-expand", "node-uuid", "got", "has-gulplog", "delegate", "log", "parseurl", "fast-redact", "humanize-number", "now-and-later", "standard", "snake-case", "assertion-error", "istextorbinary", "rcloader", "win-release", "engine.io-client", "bower-config", "jsonfile", "stylelint", "uri-js", "connect-mongo", "shush", "isurl", "readline-sync", "pascalcase", "lowercase-keys", "user", "postcss-nesting", "thenify", "multicast-dns", "ansi-yellow", "scope-analyzer", "fclone", "es5-ext", "babel-plugin-transform-async-generator-functions", "pg-connection-string", "inflight", "mongodb-core", "portscanner", "uglify-js", "through2-concurrent", "camelcase", "follow-redirects", "ieee754", "culvert", "array-reduce", "is-svg", "num2fraction", "level-errors", "arr-flatten", "rc-steps", "csstype", "copy-descriptor", "urix", "async-promise-queue", "fancy-log", "file-entry-cache", "react-addons-test-utils", "static-extend", "parse-cache-control", "package-json", "caller-path", "web3-eth-iban", "jest-message-util", "pluralize", "raw-body", "workbox-core", "multiparty", "array-each", "enabled", "restify", "p-map", "lodash.assign", "url-parse-lax", "character-reference-invalid", "websocket", "heimdalljs-logger", "web3-core-promievent", "react-input-autosize", "ansi-white", "setprototypeof", "hash.js", "secp256k1", "jest-config", "memorystream", "x-xss-protection", "to-no-case", "path-root", "map-cache", "envify", "babel-preset-flow", "workbox-webpack-plugin", "rc-slider", "lodash-es", "prettier-linter-helpers", "css-what", "w3c-hr-time", "filenamify", "make-error", "glob", "babel-plugin-transform-flow-strip-types", "babel-plugin-syntax-trailing-function-commas", "grunt-contrib-cssmin", "forwarded", "terminal-paginator", "d3-drag", "uuid", "angular-ui-router", "pixrem", "cssesc", "unist-util-visit", "good-listener", "regenerator-transform", "abbrev", "console-browserify", "animate.css", "postcss", "dot", "can-symlink", "to-buffer", "npm-run-path", "type-is", "error-ex", "scrypt.js", "lodash.escape", "locate-path", "colors", "terser", "gauge", "hmac-drbg", "restify-errors", "web3-utils", "bail", "d3", "eslint-plugin-react", "ansi-green", "big.js", "postcss-preset-env", "fs-write-stream-atomic", "https-browserify", "pathval", "sugar", "is-decimal", "callsite", "fs.realpath", "are-we-there-yet", "success-symbol", "is-directory", "is-module", "end-of-stream", "pug-attrs", "ci-info", "di", "is-png", "watch", "node-gyp", "stringify-object", "detect-port-alt", "pg-pool", "react-modal", "bunyan", "requires-port", "gonzales-pe", "commondir", "d3-hierarchy", "blueimp-md5", "combined-stream", "typechecker", "shallowequal", "vue-template-compiler", "change-emitter", "d3-zoom", "collapse-white-space", "nunjucks", "xpc-connection", "rc-menu", "babel-plugin-transform-es2015-literals", "babel-plugin-syntax-jsx", "d3-brush", "mquery", "radium", "deep-equal", "eslint-config-prettier", "check-types", "make-iterator", "babelify", "known-css-properties", "dasherize", "cssdb", "wide-align", "remark-stringify", "postcss-svgo", "flexbuffer", "urllib", "camel-case", "killable", "optparse", "array-equal", "lodash.isfinite", "unist-util-visit-parents", "graphql", "constants-browserify", "require-main-filename", "es6-symbol", "preserve", "compress-commons", "accord", "babel-plugin-transform-es2015-computed-properties", "extend", "jest-changed-files", "snapdragon-node", "extract-text-webpack-plugin", "copy-concurrently", "rttc", "inline-style-prefixer", "is-ci", "promisify-node", "map-visit", "warning-symbol", "xhr2", "rc-pagination", "postcss-place", "deep-eql", "ansi-inverse", "optimize-css-assets-webpack-plugin", "coa", "unicode-5.2.0", "is-bluebird", "then-request", "component-bind", "lodash.keys", "deep-assign", "global-dirs", "@svgr", "ast-types-flow", "better-assert", "node-notifier", "style-loader", "request-promise", "passport-oauth2", "map-stream", "verror", "pop-iterate", "diff", "d3-dispatch", "intl-relativeformat", "parley", "block-stream", "glob-watcher", "clone-stats", "fragment-cache", "wiredep-cli", "three", "https-proxy-agent", "native-duplexpair", "serve-favicon", "ethers", "source-map-resolve", "which-module", "jest-worker", "ansi-dim", "saslprep", "koa-logger", "draft-js", "md5.js", "postcss-color-hex-alpha", "postcss-focus-within", "balanced-match", "depd", "has", "js-levenshtein", "broccoli-persistent-filter", "is-regexp", "regjsparser", "lodash.isarray", "is-unc-path", "a-sync-waterfall", "babel-messages", "sax", "functional-red-black-tree", "easy-extender", "maxmin", "metro-cache", "anchor", "natives", "reselect", "postcss-flexbugs-fixes", "dom-matches", "base64-js", "json-schema", "proxy-from-env", "is", "cuid", "faker", "postcss-safe-parser", "unirest", "bodec", "jest", "grunt-cli", "any-base", "jest-runtime", "growl", "postcss-normalize-repeat-style", "table-layout", "concat-stream", "has-values", "filename-reserved-regex", "xhr2-cookies", "split", "uglify-es", "clear", "sockjs", "stat-mode", "nib", "internal-ip", "babel-plugin-syntax-export-extensions", "topo", "ajv-keywords", "useragent", "boxen", "cycle", "postcss-merge-rules", "is-gif", "url-template", "match-stream", "function.prototype.name", "messageformat", "css-color-keywords", "pac-resolver", "react-router", "parse-bmfont-ascii", "minimist-options", "eventemitter3", "eventemitter2", "istanbul-lib-instrument", "is-lower-case", "unified", "typedarray-to-buffer", "duplexer2", "duplexer3", "graceful-fs", "cli-width", "tty-browserify", "clean-css", "ansi-bgyellow", "to-regex", "color-convert", "xmlhttprequest", "arr-swap", "load-json-file", "debug", "postcss-page-break", "d3-shape", "ansi-cyan", "steno", "d3-format", "jsesc", "rc-dialog", "has-ansi", "idna-uts46-hx", "character-entities-html4", "ansi-underline", "for-in", "domutils", "import-cwd", "phantomjs-prebuilt", "mem-fs", "word-wrap", "webpack-hot-middleware", "jsprim", "select-hose", "memoizee", "opn", "replace", "math-expression-evaluator", "import-lazy", "parseqs", "is-negative-zero", "workerpool", "react-event-listener", "debounce", "chartjs-color-string", "pug-error", "react-bootstrap", "p-pipe", "fs-extra", "private", "gulp-replace", "postcss-color-rgba-fallback", "prompt-radio", "mute-stream", "text-encoding", "json3", "linkify-it", "browserify-zlib", "common-tags", "asn1.js", "escape-html", "escape-regexp", "apollo-link", "react-redux", "supertest", "jest-regex-util", "ternary-stream", "console-stream", "complex.js", "flatten", "os-browserify", "printj", "postcss-gap-properties", "lodash._shimkeys", "cacheable-request", "dtrace-provider", "umd", "postcss-font-variant", "ssh2", "is-installed-globally", "parse-asn1", "pm2-deploy", "buffer-xor", "lodash.merge", "xmlchars", "web3", "hyphenate-style-name", "cors", "plugin-error", "bin-version-check", "remove-bom-stream", "is-binary-path", "file-uri-to-path", "chownr", "pino-std-serializers", "qjobs", "domelementtype", "accepts", "html-minifier", "replace-ext", "zen-observable-ts", "node-version", "plur", "liftoff", "pug-lexer", "web3-net", "babel-plugin-transform-es2015-duplicate-keys", "detect-port", "js-tokens", "workbox-cacheable-response", "react-slick", "vfile-message", "lodash-node", "is-object", "babel-preset-react-app", "mocha", "sort-keys", "doctrine", "formidable", "is-supported-regexp-flag", "npm-packlist", "async-foreach", "stream-combiner", "lodash.omit", "@vue", "compression", "noop-logger", "jwt-decode", "vue-template-es2015-compiler", "one-time", "ansi-wrap", "to-arraybuffer", "browser-sync", "serve-index", "editions", "web3-core-requestmanager", "textextensions", "passport-oauth", "pako", "d3-time", "safe-buffer", "path-is-inside", "filenamify-url", "color-support", "pgpass", "escape-regexp-component", "mathjs", "change-case", "merge-source-map", "postcss-normalize-string", "object-assign", "ccount", "detective", "markdown-it", "iniparser", "form-data", "union", "htmlescape", "react-router-redux", "symbol-observable", "trim", "postcss-less", "file-sync-cmp", "sequelize", "history", "has-symbols", "@samverschueren", "falafel", "jsbn", "babel-plugin-debug-macros", "stylehacks", "bs58check", "fetch-cookie", "lodash._basevalues", "browser-sync-client", "sanitize-html", "indx", "is-jpg", "css-unit-converter", "prompt-actions", "gulp-template", "event-emitter", "path-posix", "child-process-promise", "for-own", "@emotion", "babel-plugin-syntax-async-generators", "promise-inflight", "rxjs", "fsevents", "d3-time-format", "fast-json-stable-stringify", "node-gyp-build", "event-loop-inspector", "realpath-native", "acorn-node", "svg-tags", "shasum", "randomhex", "helmet-csp", "mkdirp", "bn.js", "repeat-string", "escape-string-regexp", "restore-cursor", "react-transition-group", "rc-checkbox", "babel-types", "sorted-array-functions", "cssnano-util-raw-cache", "timm", "http-proxy-middleware", "errlop", "global", "normalize-scroll-left", "shebang-regex", "koa-router", "shellwords", "sass-loader", "reduce-function-call", "cssnano-util-get-arguments", "postcss-html", "socks-proxy-agent", "define-property", "grunt-contrib-jshint", "busboy", "es-to-primitive", "strip-outer", "trim-trailing-lines", "elliptic", "decode-uri-component", "browserify-sha3", "web3-bzz", "path-browserify", "string", "http-signature", "koa-compose", "tildify", "zone.js", "pstree.remy", "enqueue", "pm2-axon-rpc", "intl-messageformat", "has-generators", "leven", "react-addons-shallow-compare", "gud", "unique-random-array", "boolbase", "resolve-cwd", "ansi-bgblack", "puppeteer", "lodash.pick", "is-in-browser", "safefs", "array-includes", "sockjs-client", "add-dom-event-listener", "isobject", "xregexp", "hexlet-pairs", "css-color-function", "prettyjson", "prism-media", "font-awesome", "jsonschema", "react-test-renderer", "json2csv", "find-up", "fbemitter", "http-response-object", "cloneable-readable", "brcast", "rollup", "mv", "jest-mock", "markdown-table", "node-emoji", "thunkify", "is-my-ip-valid", "postcss-replace-overflow-wrap", "wiredep", "lru-queue", "browserify-rsa", "spdy-transport", "growly", "babel-preset-fbjs", "resolve-options", "lower-case-first", "hoopy", "address", "grouped-queue", "move-concurrently", "@serialport", "normalize-url", "isbinaryfile", "lazy", "should-type-adaptors", "load-bmfont", "thunkify-wrap", "indent-string", "lru-cache", "upath", "hbs", "param-case", "os", "parallel-transform", "stream-throttle", "karma-webpack", "babel-plugin-transform-es2015-modules-commonjs", "marked", "fluent-ffmpeg", "cacache", "urijs", "env-paths", "cli-truncate", "mdurl", "d3-transition", "resp-modifier", "quick-temp", "rc-input-number", "getobject", "cookiejar", "postcss-minify-gradients", "pm2-multimeter", "mssql", "postgres-interval", "dom-walk", "untildify", "default-gateway", "https", "http-https", "spdx-expression-parse", "clui", "jest-haste-map", "cluster-key-slot", "gifsicle", "safe-json-parse", "cli-table-redemption", "spdy", "ienoopen", "ts-loader", "expand-template", "glob2base", "browserify-des", "pleeease-filters", "uniqs", "caw", "osx-release", "meow", "is-whitespace-character", "hiredis", "github-username", "ignore-by-default", "resize-observer-polyfill", "domexception", "is-plain-obj", "es6-promisify", "@csstools", "alphanum-sort", "pushdata-bitcoin", "scss-tokenizer", "chokidar", "discontinuous-range", "regexp-clone", "cssnano", "quote-stream", "pkg-up", "chai-as-promised", "pino", "pug-load", "css-select-base-adapter", "workbox-routing", "cli-table2", "write", "foreach", "rmc-feedback", "nyc", "array-from", "react-dnd-html5-backend", "postcss-color-function", "slush", "babel-cli", "gtoken", "karma-mocha", "sinon", "levn", "babel-helper-optimise-call-expression", "metro-minify-uglify", "browserify", "regexpu-core", "scmp", "docopt", "natural", "@babel", "ua-parser-js", "git-sha1", "q", "classnames", "brorand", "media-typer", "lodash.flattendeep", "babel-template", "typical", "ast-types", "rc-calendar", "postcss-reduce-initial", "safe-regex", "reinterval", "detect-conflict", "webpack-merge", "git-node-fs", "postcss-colormin", "mimic-fn", "stack-trace", "electron-download", "workbox-broadcast-cache-update", "builtins", "amqplib", "memory-fs", "platform", "multiline", "babel-plugin-transform-es2015-modules-systemjs", "bcryptjs", "postcss-modules-values", "ecdsa-sig-formatter", "is-number-like", "scandirectory", "csv-generate", "babel-plugin-transform-es2015-parameters", "lodash.camelcase", "errorhandler", "tinytim", "gulp-imagemin", "gulp-git", "is-utf8", "eslint-visitor-keys", "xpipe", "packet-reader", "pug-runtime", "watchify", "crypto", "eachr", "ethereumjs-util", "vinyl-buffer", "co-from-stream", "date-format", "mysql2", "nice-try", "is-arrayish", "react-motion", "prompt-checkbox", "crc32-stream", "exenv", "serve-static", "gulplog", "parse-bmfont-xml", "is-alphanumeric", "koa-send", "named-placeholders", "jest-environment-jsdom", "dockerode", "css-url-regex", "electron-to-chromium", "is-path-inside", "external-editor", "ejs", "argx", "tmpl", "ansi-grey", "redux-thunk", "d3-array", "d3-path", "argv", "@angular", "uglify-to-browserify", "mime", "babel-preset-es2015", "es6-denodeify", "is-extendable", "css-in-js-utils", "rlp", "ora", "units-css", "event-stream", "regjsgen", "resolve-path", "mkdirp-promise", "@protobufjs", "http-deceiver", "strip-ansi", "jwa", "imurmurhash", "emotion", "clone-deep", "create-react-class", "trim-newlines", "character-parser", "make-error-cause", "babel-helper-define-map", "filename-regex", "miller-rabin", "specificity", "unc-path-regex", "angular", "expand-range", "livereload-js", "underscore.string", "parseuri", "should-format", "node-modules-regexp", "flatiron", "bitcoin-ops", "array-flatten", "rc-tree-select", "jss-nested", "rx-lite-aggregates", "h2x-plugin-jsx", "gulp-install", "prettier", "p-limit", "eyes", "showdown", "neo-async", "google-auth-library", "workbox-build", "registry-auth-token", "vorpal", "concat-map", "babel-plugin-syntax-function-bind", "grunt", "web3-providers-http", "is-property", "argsarray", "stealthy-require", "mysql", "optimist", "log-ok", "omit.js", "center-align", "yallist", "lodash.templatesettings", "postcss-color-rgb", "p-cancelable", "getpass", "path-type", "caller-callsite", "opencollective-postinstall", "prr", "lodash._objecttypes", "eslint-plugin-prettier", "postcss-media-minmax", "lodash.get", "tinycolor2", "eth-ens-namehash", "postcss-image-set-function", "gkt", "win-fork", "math-interval-parser", "eventsource", "rc-table", "es6-templates", "absolute-path", "destroy", "split-string", "bcrypt", "d3-contour", "pngquant-bin", "knex", "buffer", "lodash.isequal", "karma-jasmine", "create-ecdh", "highlight.js", "react-tap-event-plugin", "array-series", "bs-snippet-injector", "shelljs", "bluebird", "bootstrap-sass", "readline-utils", "forever", "generate-object-property", "autoprefixer", "vue-hot-reload-api", "async-limiter", "cosmiconfig", "phin", "h2x-generate", "read-chunk", "archy", "netmask", "stringify-entities", "sumchecker", "railroad-diagrams", "ylru", "custom-event", "amd-name-resolver", "babel-traverse", "@firebase", "chrome-trace-event", "bytebuffer", "webpack-dev-server", "xml", "zrender", "import-from", "mixin-deep", "ext-list", "h2x-traverse", "shimmer", "asn1", "gulp", "only", "babel-plugin-emotion", "lodash.set", "css-declaration-sorter", "js-cookie", "escape-latex", "babel-plugin-module-resolver", "postcss-modules-extract-imports", "header-case", "tiny-lr", "core-js", "spdx-license-ids", "nconf", "eslint-config-standard-jsx", "invariant", "ssf", "isarray", "syntax-error", "deprecate", "postcss-normalize-charset", "randomstring", "run-async", "fbjs-css-vars", "proto-list", "find-index", "through", "async-disk-cache", "normalize-selector", "canonical-path", "buffer-equal", "browser-stdout", "hoek", "callsites", "socket.io", "stream-shift", "color-name", "frameguard", "whatwg-fetch", "flow-bin", "metro-react-native-babel-preset", "axobject-query", "jss-camel-case", "jpeg-js", "object.entries", "pump", "ambi", "prepend-http", "range-parser", "vizion", "replacestream", "is-primitive", "dottie", "postcss-ordered-values", "broccoli-debug", "babel-plugin-transform-async-to-generator", "strip-dirs", "state-toggle", "clipboardy", "request-promise-native", "vue", "fs-tree-diff", "postcss-scss", "decompress-tarbz2", "babel-plugin-transform-react-jsx-self", "d3-timer", "json-loader", "pixelmatch", "es6-map", "es6-shim", "babel-plugin-transform-decorators-legacy", "ltgt", "selenium-webdriver", "babel-plugin-syntax-class-constructor-call", "color", "schema-utils", "to-absolute-glob", "nodegit", "readline-ui", "strip-bom-buf", "wrappy", "csextends", "antd", "jsdom", "p-map-series", "indefinite-observable", "align-text", "file-saver", "acorn-dynamic-import", "jss-global", "write-stream", "deasync", "unpipe", "arrify", "encodeurl", "enable", "content-disposition", "css-vendor", "constantinople", "enquire.js", "cliui", "i18n", "bonjour", "semver-diff", "p-is-promise", "object-is", "websocket-extensions", "jest-diff", "lodash", "npm-run-all", "random-bytes", "babel-plugin-transform-es2015-sticky-regex", "nomnom", "@sinonjs", "core-util-is", "duplexer", "array-differ", "forever-agent", "postcss-minify-font-values", "lazystream", "to-through", "taffydb", "read-only-stream", "jsx-ast-utils", "commander", "cls-bluebird", "google-p12-pem", "utila", "object.assign", "utile", "lodash.padend", "helmet", "keygrip", "jss-props-sort", "jest-watcher", "sugar-core", "redux-logger", "string-length", "npm-bundled", "randomatic", "events", "es-abstract", "noble", "escodegen", "postcss-discard-overridden", "vue-loader", "archive-type", "utf8", "redis-errors", "lodash.foreach", "is-url", "decompress", "director", "tar-stream", "widest-line", "toidentifier", "aws-sdk", "protobufjs", "tarn", "xpath.js", "html-tags", "ansi-blue", "cache-content-type", "postcss-jsx", "babel-jest", "adler-32", "tar.gz", "postcss-pseudo-class-any-link", "postcss-focus-visible", "pac-proxy-agent", "get-func-name", "googleapis-common", "string.prototype.trim", "log-driver", "babel-plugin-syntax-dynamic-import", "when", "node-rest-client", "path-dirname", "normalize-package-data", "@gulp-sourcemaps", "jshint", "unicode", "babel-plugin-syntax-object-rest-spread", "touch", "styled-components", "defaults", "pouchdb", "d3-geo", "sqlite3", "twit", "blob", "postcss-normalize-whitespace", "dotenv", "postgres-bytea", "babel", "server-destroy", "kareem", "buffer-alloc-unsafe", "psl", "read", "swig", "@ant-design", "dns-prefetch-control", "chainsaw", "get-stream", "moo", "scheduler", "write-file-atomic", "amp", "stylelint-config-standard", "fs-updater", "babel-plugin-transform-react-jsx", "semver-regex", "get-port", "btoa", "xmldoc", "co-body", "path-root-regex", "extsprintf", "os-homedir", "enhanced-resolve", "semver", "gulp-match", "configstore", "execa", "swarm-js", "yauzl", "mime-db", "hpack.js", "fast-safe-stringify", "vinyl-bufferstream", "upper-case", "postcss-overflow-shorthand", "confusing-browser-globals", "vasync", "elegant-spinner", "postcss-lab-function", "matcher-collection", "fork-ts-checker-webpack-plugin-alt", "flush-write-stream", "redis", "is-boolean-object", "xmlbuilder", "utf-8-validate", "exit", "rev-path", "strip-eof", "babel-plugin-transform-es2015-typeof-symbol", "is-typedarray", "pad-component", "requireindex", "transformers", "ansi-italic", "asap", "co-prompt", "tv4", "hsl-regex", "react-native-vector-icons", "javascript-natural-sort", "create-hash", "moment-timezone", "dicer", "split-ca", "postcss-convert-values", "bs-logger", "rollup-plugin-commonjs", "sanitize-filename", "vfile-location", "babel-plugin-check-es2015-constants", "ignorefs", "uid-safe", "content-type", "object-component", "isomorphic-fetch", "postcss-styled", "tree-sync", "blessed", "rgb-regex", "cached-path-relative", "winston-transport", "lodash._reunescapedhtml", "run-queue", "resolve-pathname", "stringstream", "component-emitter", "denque", "workbox-google-analytics", "ts-node", "import-local", "component-indexof", "no-case", "is-builtin-module", "postcss-color-rebeccapurple", "home-or-tmp", "jest-each", "web3-eth-personal", "gaze", "function-bind", "kind-of", "lodash.toarray", "leaflet", "csv-stringify", "ansi-bgred", "gulp-clean", "immutability-helper", "metro-source-map", "level", "with", "log4js", "hash-sum", "cross-env", "istanbul-lib-coverage", "has-symbol-support-x", "colorspace", "cssnano-preset-default", "@nodelib", "react-side-effect", "object.map", "flatstr", "lodash._reinterpolate", "lodash.debounce", "expect", "is-regex", "broccoli-plugin", "ssri", "pretty-format", "archiver-utils", "copy-paste", "eslint-plugin-es", "prompt-question", "imagemin", "statuses", "outpipe", "tedious", "istanbul", "pidusage", "jest-resolve", "string.prototype.padend", "stdout-stream", "webpack-stream", "h2x-types", "jpegtran-bin", "babel-helper-builder-binary-assignment-operator-visitor", "is-alphanumerical", "xmlhttprequest-ssl", "next-tick", "babylon", "css-tree", "lodash.some", "secure-keys", "babel-plugin-istanbul", "is-negated-glob", "ansi", "worker-farm", "kleur", "truncate-utf8-bytes", "json-buffer", "find-root", "diffie-hellman", "finalhandler", "ansi-bgcyan", "fs-promise", "rollup-plugin-babel", "@webcomponents", "watchpack", "postcss-minify-params", "pug-filters", "gulp-concat", "validator", "ts-jest", "get-value", "husky", "redux", "original", "buffer-alloc", "koalas", "babel-plugin-transform-es2015-unicode-regex", "lodash.union", "object.omit", "p-finally", "ajv", "vue-router", "grunt-contrib-watch", "dot-prop", "hogan.js", "cssom", "postcss-loader", "timsort", "es6-weak-map", "lodash.isarguments", "eslint-import-resolver-node", "color-string", "is-date-object", "babel-helper-builder-react-jsx", "crc-32", "zmq", "node-watch", "immutable", "sequencify", "utils-merge", "rc-trigger", "json-schema-traverse", "cipher-base", "has-value", "dateformat", "rc", "ansi-strikethrough", "min-document", "util", "hubot", "passport-local", "napi-build-utils", "progress-stream", "proxy-addr", "serialport", "hooker", "npmlog", "whatwg-mimetype", "parse-filepath", "string-convert", "react-transform-hmr", "eslint-rule-composer", "pullstream", "cssstyle", "babel-plugin-import", "sane", "web3-eth-contract", "require-uncached", "browserify-sign", "dom-converter", "anymatch", "cookies", "dom-storage", "eslint-config-react-app", "jest-docblock", "wrap-ansi", "keccak", "any-shell-escape", "eslint-plugin-jsx-a11y", "sigmund", "negotiator", "run-node", "docker-modem", "winston-daily-rotate-file", "undeclared-identifiers", "d3-interpolate", "omggif", "doctypes", "rc-editor-mention", "dom-serializer", "bitcoinjs-lib", "prebuild-install", "gulp-rev", "gh-got", "async-listener", "connect-history-api-fallback", "to-array", "loose-envify", "tslib", "amp-message", "terraformer", "bplist-parser", "remove-trailing-separator", "isemail", "camelize", "node-abi", "agent-base", "firebase", "double-ended-queue", "react-dropzone", "cryptiles", "base64-arraybuffer", "expect-ct", "postcss-selector-parser", "babel-plugin-transform-es2015-template-literals", "rc-progress", "wcwidth", "os-tmpdir", "gulp-uglify", "object.pick", "base", "handle-thing", "dns-equal", "options", "get-uri", "number-is-nan", "array-uniq", "crypto-browserify", "loader-fs-cache", "json5", "get-stdin", "send", "webpack-dev-middleware", "cli-boxes", "rc-time-picker", "drbg.js", "select", "react-intl", "executable", "wordwrapjs", "lodash.mergewith", "express-unless", "nodemailer", "hide-powered-by", "info-symbol", "dom-urls", "archiver", "update-notifier", "eslint-config-airbnb-base", "babel-helpers", "h2x-core", "flat", "triple-beam", "oboe", "big-integer", "swap-case", "clean-up-path", "find-versions", "web3-providers-ws", "slice-ansi", "shell-quote", "web3-core-method", "void-elements", "any-promise", "check-error", "eslint-loader", "ramda", "fastclick", "just-extend", "merge-trees", "micromatch", "watchr", "kuler", "del", "morgan", "jest-validate", "twilio", "dargs", "web3-providers-ipc", "prompt", "propprop", "character-entities", "multimatch", "afinn-165", "iota-array", "p-timeout", "zip-stream", "sharp", "figlet", "ember-rfc176-data", "toggle-array", "yeast", "hpkp", "acorn-walk", "timers-ext", "cline", "validate-npm-package-name", "csv", "css", "gcp-metadata", "detect-indent", "is-npm", "fs", "orchestrator", "homedir-polyfill", "abstract-leveldown", "dependency-graph", "babel-preset-es2017", "babel-preset-es2016", "babel-helper-explode-assignable-expression", "jszip", "websocket-driver", "eslint-plugin-babel", "rc-switch", "builtin-modules", "jest-environment-node", "create-emotion", "merge-descriptors", "argparse", "github", "wrench", "to-fast-properties", "xdg-basedir", "handlebars", "jest-pnp-resolver", "json-parse-better-errors", "stylus", "deep-metrics", "react-app-polyfill", "latest-version", "buffer-fill", "jsonwebtoken", "broadway", "rc-rate", "phantomjs", "fined", "passport-strategy", "xml-name-validator", "defer-to-connect", "ansi-colors", "pend", "istanbul-lib-hook", "jasmine-core", "typeforce", "stream-each", "eslint-plugin-node", "find-my-way", "yn", "graphql-tools", "icss-replace-symbols", "babel-helper-get-function-arity", "exec-buffer", "isnumeric", "renderkid", "es6-error", "slice-stream", "fs-mkdirp-stream", "nugget", "x-is-string", "jss-default-unit", "metro-config", "read-pkg-up", "caseless", "oauth-sign", "co-fs-extra", "unique-string", "cli-color", "repeating", "esrecurse", "unquote", "stylelint-config-recommended", "contains-path", "pirates", "object-inspect", "pointer-symbol", "rc-tabs", "dir-glob", "connect", "mime-types", "object-copy", "httpreq", "child_process", "buffers", "ftp", "workbox-strategies", "into-stream", "postcss-image-set-polyfill", "xhr-request-promise", "append-transform", "read-cache", "etag", "listr-update-renderer", "inquirer", "damerau-levenshtein", "webpack-cli", "d3-dsv", "metro-babel7-plugin-react-transform", "inert", "quick-format-unescaped", "pug", "gulp-sourcemaps", "fileset", "promise-polyfill", "decompress-response", "espree", "ansi-styles", "cookie", "acorn", "is-natural-number", "is-posix-bracket", "ansi-bgblue", "is-callable", "deep-is", "universalify", "recast", "sylvester", "react-error-overlay", "body-parser", "prop-types", "fraction.js", "babel-preset-jest", "css-color-names", "define-properties", "encoding", "unicode-match-property-value-ecmascript", "proxy-agent", "superagent", "flaverr", "string-width", "ansi-bggreen", "unique-stream", "postcss-color-hwb", "speedometer", "unist-util-find-all-after", "metalsmith", "crypto-js", "simple-concat", "level-packager", "is-string", "koa", "on-headers", "unicode-canonical-property-names-ecmascript", "vxx", "dom-serialize", "mock-fs", "lowdb", "source-map", "logalot", "ignorepatterns", "rgb-hex", "ncp", "set-blocking", "harmony-reflect", "needle", "find-babel-config", "immediate", "unicode-match-property-ecmascript", "node-addon-api", "bower", "from2", "path-exists", "babel-plugin-syntax-class-properties", "jquery", "sonic-boom", "supports-color", "env-variable", "in-publish", "sha.js", "is-plain-object", "babel-plugin-transform-es2015-modules-amd", "loader-runner", "onecolor", "request-progress", "postcss-custom-properties", "exit-hook", "level-iterator-stream", "lodash._reescape", "wbuf", "jest-jasmine2", "download", "pug-strip-comments", "strip-bom-string", "scrypt", "findup-sync", "eslint-plugin-standard", "nanomatch", "is-upper-case", "is-color-stop", "utility", "array-unique", "time-stamp", "lpad-align", "pinkie", "prompt-base", "registry-url", "extend-shallow", "extract-zip", "lodash.uniq", "rc-tooltip", "babel-plugin-syntax-exponentiation-operator", "hosted-git-info", "bowser", "log-symbols", "setimmediate", "sntp", "browser-sync-ui", "is-glob", "array-parallel", "postcss-load-config", "http-parser-js", "portfinder", "react", "minimalistic-assert", "uri-path", "ps-tree", "charm", "term-size", "jss", "email-addresses", "detect-libc", "xml-parse-from-string", "js-base64", "broccoli-source", "node-sass", "gulp-sass", "tiny-secp256k1", "eslint-plugin-promise", "buffer-writer", "sentence-case", "buffer-indexof", "gulp-typescript", "is-nan", "js-beautify", "tr46", "xcode", "cheerio", "babel-plugin-transform-es2015-destructuring", "test-value", "identity-obj-proxy", "flat-cache", "immer", "punycode", "optipng-bin", "postinstall-build", "nssocket", "bfj", "ansi-bgwhite", "inflection", "rc-editor-core", "d3-scale-chromatic", "enzyme", "hash-base", "bcrypt-pbkdf", "lodash.last", "is-extglob", "referrer-policy", "digest-header", "html-encoding-sniffer", "glogg", "gulp-load-plugins", "ewma", "express", "rootpath", "mamacro", "image-size", "os-filter-obj", "longest", "web3-core-helpers", "validate-npm-package-license", "d3-collection", "css-to-react-native", "resolve", "ansi-black", "merge2", "bytes", "resolve-dir", "choices-separator", "crc", "catharsis", "append-field", "memory-cache", "pug-parser", "babel-plugin-transform-es2015-object-super", "is-valid-glob", "memory-pager", "@pm2", "art", "big-number", "ip-regex", "jade", "mongoose", "imagemin-optipng", "merge-stream", "ecc-jsbn", "rc-select", "timers-browserify", "grunt-contrib-concat", "to-regex-range", "walk-sync", "pm2", "is-path-in-cwd", "yosay", "gulp-eslint", "keypress", "nopt", "dot-case", "array-filter", "lodash._htmlescapes", "convert-source-map", "extract-opts", "postcss-discard-empty", "quick-lru", "babel-preset-latest", "babel-helper-call-delegate", "typedarray", "react-virtualized", "es6-set", "logform", "require-dir", "babel-plugin-add-module-exports", "postcss-color-functional-notation", "clone-regexp", "node-fetch", "jest-runner", "shallow-copy", "sisteransi", "scoped-regex", "deprecated-decorator", "retry-axios", "ansi-regex", "github-from-package", "postcss-selector-not", "d3-selection", "mdast-util-compact", "gulp-if", "keccakjs", "home-path", "decompress-tar", "postcss-color-gray", "html-loader", "rollup-plugin-node-resolve", "node-releases", "raf", "markdown", "rc-drawer", "http-errors", "http-server", "cli-spinner", "globals", "xtend", "koa-bodyparser", "pm2-axon", "caniuse-lite", "lodash.map", "connect-multiparty", "gulp-watch", "pg", "any-observable", "babel-helper-remap-async-to-generator", "@uirouter", "pn", "intl-format-cache", "react-dev-utils", "is-my-json-valid", "react-helmet", "react-lazy-load", "babel-plugin-syntax-decorators", "object-hash", "web3-eth-accounts", "basic-auth", "rst-selector-parser", "npm-conf", "react-onclickoutside", "browser-split", "coveralls", "error-symbol", "batch", "webpack-log", "sprintf-js", "connect-flash", "lodash.template", "error", "streamfilter", "graceful-readlink", "pumpify", "request-promise-core", "eslint-config-standard", "babel-plugin-transform-class-properties", "ensure-posix-path", "normalize-range", "p-reduce", "is-stream", "array-slice", "lodash.throttle", "open", "fibers", "babel-plugin-transform-function-bind", "pretty-hrtime", "expand-brackets", "to-camel-case", "debug-log", "iterall", "fbjs", "workbox-navigation-preload", "react-timer-mixin", "colornames", "uc.micro", "is-expression", "browserify-cipher", "babel-plugin-transform-es2015-for-of", "d3-polygon", "keyv", "@polymer", "should-type", "strip-bom-stream", "moment", "imagemin-gifsicle", "download-git-repo", "pug-walk", "js-yaml", "workbox-precaching", "grunt-known-options", "sha3", "sha1", "irregular-plurals", "faye-websocket", "ansi-hidden", "mobx", "inflation", "chartjs-color", "js-stringify", "assert-plus", "ammo", "coffee-script", "glob-parent", "is-windows", "ansi-reset", "gray-matter", "regenerate-unicode-properties", "on-finished", "lodash.difference", "global-modules-path", "angular-sanitize", "duplexify", "ajv-errors", "indexof", "bitsyntax", "foreachasync", "nedb", "rgb", "parents", "mockjs", "degenerator", "parse-bmfont-binary", "babel-plugin-jest-hoist", "postcss-color-mod-function", "ansi-html", "lodash.isplainobject", "metro-core", "svgo", "lodash.findindex", "emojis-list", "dom-closest", "mini-css-extract-plugin", "d", "array.prototype.flat", "broccoli-kitchen-sink-helpers", "jsonify", "lcov-parse", "ignore", "flux", "capture-exit", "bser", "is-fullwidth-code-point", "call-me-maybe", "pkg-config", "base64id", "methods", "istanbul-lib-source-maps", "simple-plist", "require_optional", "command-exists", "left-pad", "bounce", "acorn-globals", "has-color", "intl-messageformat-parser", "dont-sniff-mimetype", "eth-lib", "babel-generator", "retry", "openurl", "unicode-property-aliases-ecmascript", "console-control-strings", "lodash._isnative", "hsts", "unset-value", "lodash._reevaluate", "slash", "right-align", "shallow-clone", "bin-check", "relateurl", "rc-animate", "log-utils", "bl", "babel-plugin-transform-exponentiation-operator", "wrap-fn", "step", "nearley", "is-generator-fn", "css-stringify", "popper.js", "keycode", "react-dnd", "querystringify", "whatwg-url", "chart.js", "postcss-apply", "estree-walker", "esquery", "stacktrace-parser", "engine.io", "subarg", "gulp-filter", "front-matter", "string_decoder", "intl", "codepage", "default-user-agent", "fast-glob", "web3-core", "gh-pages", "lodash._escapestringchar", "lodash.isobject", "pkginfo", "json-stable-stringify-without-jsonify", "ts-helpers", "module-deps", "hapi", "gulp-mocha", "gulp-jshint", "json2mq", "null-check", "markdown-escapes", "webpack-sources", "errno", "pg-types", "long", "columnify", "is-scoped", "vendors", "bigi", "stylis", "eslint-config-airbnb", "d3-force", "systemjs", "method-override", "object-path", "xpath", "fast-ordered-set", "compressible", "append-buffer", "@jimp", "bip66", "read-pkg", "fork-stream", "webpack-node-externals", "atob", "create-react-context", "path-to-regexp", "deep-extend", "reduce-css-calc", "mini-store", "caller", "emitter-listener", "aes-js", "modify-filename", "element-ui", "prompt-choices", "set-getter", "defined", "chai", "log-update", "raw-loader", "expand-tilde", "warning", "web3-shh", "workbox-streams", "iferr", "browser-resolve", "workbox-background-sync", "phantom", "dom-align", "amqp", "concat-with-sourcemaps", "postcss-custom-selectors", "crypt", "postcss-syntax", "nan", "value-or-function", "csv-parse", "ansi-align", "xmldom", "metro-resolver", "h2x-parse", "postcss-attribute-case-insensitive", "babel-extract-comments", "babel-helper-vue-jsx-merge-props", "rc-form", "mongodb", "backbone", "parse5", "readline2", "minipass", "throttle-debounce", "command-line-usage", "emoji-regex", "last-call-webpack-plugin", "eslint-utils", "randomfill", "lead", "smart-buffer", "object.defaults", "fill-range", "lodash.tail", "array-back", "karma", "is-path-cwd", "walker", "fresh", "thunky", "once", "browserslist", "loglevelnext", "agentkeepalive", "jimp", "scoped-http-client", "string-template", "cli-table", "is-alphabetical", "math-random", "websocket-stream", "generate-function", "x-is-array", "eslint-module-utils", "library.min.js", "v8flags", "rc-tree", "yamljs", "jstransformer", "decamelize-keys", "pnp-webpack-plugin", "camelcase-keys", "stable", "ripemd160", "loud-rejection", "browser-pack", "unzip", "xml2js", "imagemin-svgo", "resolve-from", "valid-url", "process-nextick-args", "multicast-dns-service-types", "seed-random", "for-each", "electron", "express-jwt", "trough", "underscore", "mout", "vlq", "code-point-at", "postgres-date", "symbol-tree", "forever-monitor", "bufferstreams", "ansi-bold", "fast-diff", "which-pm-runs", "rc-hammerjs", "postcss-minify-selectors", "level-codec", "grunt-legacy-log-utils", "standard-engine", "global-prefix", "cfb", "is-function", "http-basic", "cron", "cache-base", "rc-collapse", "winston", "mktemp", "lolex", "is-symbol", "git-clone", "apparatus", "vinyl-fs", "decompress-unzip", "postgres-array", "prompts", "clipboard", "find-replace", "express-session", "hsla-regex", "mitt", "binary-search-tree", "body", "babel-plugin-transform-object-rest-spread", "thenify-all", "isexe", "gulp-changed", "gm", "axios", "normalize-path", "pause-stream", "extglob", "encoding-down", "cyclist", "remark", "cookie-signature", "text-hex", "metro", "utf8-byte-length", "recursive-readdir", "pkg-conf", "lodash.groupby", "virtual-dom", "JSONStream", "is-root", "rx-lite", "reflect-metadata", "should-equal", "wif", "babel-helper-replace-supers", "cross-spawn", "combine-lists", "is-relative", "babel-plugin-transform-es2015-arrow-functions", "gulp-plumber", "utif", "array-union", "postcss-initial", "nth-check", "bindings", "feature-policy", "iconv-lite", "use", "from", "broccoli-funnel", "jest-leak-detector", "jest-resolve-dependencies", "source-list-map", "recompose", "capture-stack-trace", "nock", "node-dir", "bufferutil", "ultron", "ascli", "gulp-util", "adm-zip", "node-cache", "mdn-data", "bin-version", "nano-json-stream-parser", "MD5", "circular-json", "react-scripts", "karma-chrome-launcher", "metro-babel-register", "humanize-url", "merkle-lib", "json-stable-stringify", "istanbul-api", "strip-json-comments", "tar", "process", "postcss-unique-selectors", "eslint-restricted-globals", "pbkdf2", "unique-filename", "create-error-class", "stream-counter", "koa-static", "mixin-object", "ipaddr.js", "memoize-one", "should-util", "inversify", "cookie-parser", "googleapis", "cli-spinners", "fs-constants", "generic-pool", "is-hexadecimal", "toml", "pretty-bytes", "user-home", "npm", "klaw", "postcss-normalize-unicode", "fast-deep-equal", "frac", "lodash.padstart", "error-inject", "serialize-javascript", "help-me", "decamelize", "babel-plugin-transform-regenerator", "output-file-sync", "stream-consume", "lodash.values", "delayed-stream", "loglevel", "caniuse-api", "passport-facebook", "node-cmd", "glob-stream", "vue-resource", "default-require-extensions", "sw-toolbox", "wordwrap", "eslint", "regenerator-runtime", "snapdragon-util", "binaryextensions", "babel-plugin-named-asset-import", "mustache", "webidl-conversions", "jshint-stylish", "object.values", "react-native", "postcss-value-parser", "lodash.clone", "strip-color", "bin-wrapper", "mem-fs-editor", "type-detect", "pull-stream", "gulp-rename", "throttleit", "snapdragon", "has-unicode", "static-module", "async-each-series", "asynckit", "chain-function", "express-handlebars", "web3-eth-abi", "util.promisify", "find-cache-dir", "mqtt", "posix-character-classes", "tough-cookie", "attr-accept", "babel-preset-react", "rsvp", "bignumber.js", "shallow-equal", "fs-exists-sync", "estree-is-function", "apollo-utilities", "stream-buffers", "seq-queue", "strict-uri-encode", "d3-ease", "babel-helper-bindify-decorators", "http-proxy", "hammerjs", "is-generator-function", "babel-plugin-transform-es2015-block-scoping", "postcss-custom-media", "simple-get", "react-prop-types", "workbox-range-requests", "merge", "slide", "react-devtools-core", "tracer", "lie", "babel-runtime", "seek-bzip", "har-schema", "reduce-reducers", "querystring", "inline-source-map", "clone-buffer", "postcss-pseudoelements", "istanbul-reports", "jest-serializer", "minimatch", "run-parallel", "vinyl-file", "async-validator", "buffer-from", "ret", "rc-dropdown", "css-animation", "yargs", "clone", "localforage", "to-readable-stream", "babel-plugin-transform-es2015-modules-umd", "react-icons", "delegates", "promptly", "intersperse", "data-uri-to-buffer", "fs-access", "zen-observable", "p-queue", "figgy-pudding", "unescape", "passthrough-counter", "bech32", "lodash.restparam", "multipipe", "clone-response", "postcss-media-query-parser", "isstream", "safer-buffer", "elasticsearch", "lodash._basecopy", "resumer", "dashdash", "babel-plugin-transform-class-constructor-call", "parse-entities", "postcss-message-helpers", "prop-types-extra", "@xtuc", "get-proxy", "d3-voronoi", "traverse", "sinon-chai", "semver-truncate", "nullthrows", "through2-filter", "braces", "toposort", "hawk", "pinkie-promise", "domain-browser", "pegjs", "strip-url-auth", "binary-extensions", "simple-assign", "is-promise", "babel-plugin-dynamic-import-node", "postcss-resolve-nested-selector", "htmlparser2", "mpath", "listr", "jest-get-type", "findit", "discord.js", "gulp-conflict", "rc-upload", "has-cors", "stream-combiner2", "whatwg-encoding", "currently-unhandled", "has-binary2", "des.js", "exec-sh", "individual", "chardet", "terraformer-wkt-parser", "object-keys", "ignore-walk", "copy-to", "copy-webpack-plugin", "promise-map-series", "union-value", "nanoid", "file-loader", "signal-exit", "is-data-descriptor", "require-all", "mobx-react", "level-write-stream", "throat", "optionator", "pify", "ember-cli-version-checker", "safe-json-stringify", "node-expat", "unique-slug", "@webassemblyjs", "fbjs-scripts", "combine-source-map", "stream-browserify", "postcss-reduce-transforms", "shebang-command", "lodash.sortby", "util-deprecate", "retry-as-promised", "browserify-aes", "which", "web3-eth-ens", "vuvuzela", "postcss-normalize-display-values", "soap", "de-indent", "normalize.css", "web3-eth", "co-read", "character-entities-legacy", "engine.io-parser", "function-source", "array-find-index", "propagate", "parse-headers", "xhr-request", "text-table", "assign-symbols", "d3-scale", "array-tree-filter", "performance-now", "unist-util-stringify-position", "url", "redis-parser", "request", "crypto-random-string", "react-dom", "exif-parser", "continuable-cache", "diagnostics", "responselike", "prompt-list", "style-search", "socket.io-parser", "tryer", "servify", "multer", "y18n", "postcss-color-hsl", "jquery-ui", "jest-matcher-utils", "css-select", "is-equal-shallow", "vm-browserify", "optjs", "dns-packet", "end-stream", "pause", "uid2", "jest-util", "backo2", "fecha", "restler", "babel-plugin-syntax-flow", "should", "entities", "lodash.isfunction", "mimic-response", "tape", "to-object-path", "lodash._getnative", "bplist-creator", "beeper", "title-case", "parse-glob", "argv-tools", "unherit", "levelup", "stylis-rule-sheet", "broccoli-babel-transpiler", "domhandler", "postcss-values-parser", "qs", "preact", "hash-for-dep", "get-own-enumerable-property-symbols", "cssnano-util-same-parent", "gulp-postcss", "undefsafe", "heimdalljs", "nise", "radio-symbol", "is-resolvable", "token-stream", "denodeify", "serialize-error", "postcss-font-family-system-ui", "babel-helper-hoist-variables", "babel-plugin-transform-decorators", "grunt-legacy-util", "postcss-discard-duplicates", "webpack-manifest-plugin", "keymirror", "minimalistic-crypto-utils", "bcrypt-nodejs", "sugarss", "base-64", "babel-plugin-transform-react-jsx-source", "vinyl-sourcemap", "tapable", "gulp-notify", "fast-json-parse", "nightmare", "pug-code-gen", "event-target-shim", "simple-swizzle", "query-string", "fs-copy-file-sync", "progress", "babel-plugin-transform-object-assign", "postcss-normalize-timing-functions", "astral-regex", "babel-plugin-transform-es2015-block-scoped-functions", "deferred-leveldown", "type-check", "revalidator", "content-security-policy-builder", "onetime", "eazy-logger", "byline", "jsdoc", "react-hot-loader", "typed-function", "kew", "joi", "aws-sign2", "node-forge", "cron-parser", "redux-actions", "evp_bytestokey", "rollup-pluginutils", "babel-loader", "tempfile", "stylus-loader", "figures", "symlink-or-copy", "ee-first", "node-static", "ws", "highland", "srcset", "eslint-plugin-import", "babel-preset-stage-2", "babel-preset-stage-3", "babel-preset-stage-0", "babel-preset-stage-1", "co", "error-stack-parser", "walk", "babel-preset-env", "d3-random", "table", "jsonpointer", "babel-plugin-styled-components", "indexes-of", "weak-map", "make-plural", "os-name", "css-parse", "postcss-selector-matches", "split2", "minimist", "yaml", "rc-cascader", "fastparse", "fs-minipass", "http-assert", "postcss-modules-scope", "mutationobserver-shim", "path-is-absolute", "makeerror", "xlsx", "es6-promise", "decimal.js", "babel-plugin-syntax-async-functions", "assert", "deglob", "humanize-ms", "rgba-regex", "ansi-red", "angular-animate", "remark-parse", "corser", "acorn-jsx", "randexp", "exit-on-epipe", "material-ui", "parse-json", "json-stringify-safe", "vinyl-source-stream", "chalk", "repeat-element", "lodash.isstring", "ant-design-palettes", "requirejs", "unique-random", "inherits", "source-map-url", "express-validator", "lodash.isboolean", "babel-eslint", "redux-form", "postcss-cssnext", "vinyl-sourcemaps-apply", "is-wsl", "react-proxy", "babel-plugin-transform-runtime", "path-key", "wkx", "aws4", "babel-plugin-transform-do-expressions", "redux-saga", "selfsigned", "tunnel-agent", "workbox-cache-expiration", "object.getownpropertydescriptors", "grpc", "unbzip2-stream", "eslint-scope", "brfs", "component-inherit", "has-to-string-tag-x", "http", "tslint-react", "html-comment-regex", "detect-node", "postcss-calc", "readdirp", "imagemin-jpegtran", "deep-diff", "codemirror", "value-equal", "stream-transform", "i", "colour", "lodash._basetostring", "is-subset", "http-cache-semantics", "tiny-emitter", "babel-plugin-transform-es2015-spread", "minizlib", "babel-plugin-transform-react-remove-prop-types", "create-hmac", "abab", "sync-rpc", "ansi-escapes", "toposort-class", "url-set-query", "less", "strip-indent", "gulp-less", "gulp-babel", "grunt-contrib-copy", "arr-diff", "map-obj", "bip32", "csso", "iftype", "icss-utils", "strip-hex-prefix", "serviceworker-cache-polyfill", "data-urls", "lodash.flatten", "node-int64", "saxes", "extendr", "file-stream-rotator", "is-obj", "d3-color", "raven", "please-upgrade-node", "css-loader", "collection-visit", "charenc", "node-localstorage", "@sailshq", "koa-is-json", "babel-helper-regex", "knox", "babel-code-frame", "unist-util-remove-position", "web3-core-subscriptions", "tslint", "babel-plugin-macros", "install", "osenv", "longest-streak", "sourcemap-codec", "class-utils", "make-dir", "editorconfig", "require-directory", "global-modules", "semver-store", "async", "trim-repeated", "debug-fabulous", "postcss-modules-local-by-default", "temp-dir", "test-exclude", "twitter", "redis-commands", "babel-plugin-transform-strict-mode", "postcss-logical", "node-schedule", "resolve-url", "true-case-path", "hyperquest", "tmp", "unist-util-is", "tsutils", "react-is", "cssnano-util-get-match", "pascal-case", "strip-comments", "html-webpack-plugin", "shortid", "deepmerge", "buffer-shims", "md5-file", "callback-stream", "globjoin", "estraverse", "lower-case", "vuex", "slug", "babel-plugin-syntax-do-expressions", "labeled-stream-splicer", "insert-module-globals", "is-descriptor", "snekfetch", "regenerate", "fd-slicer", "react-overlays", "number-to-bn", "grunt-legacy-log", "reduce-flatten", "static-eval", "get-caller-file", "timed-out", "vue-style-loader", "trim-right", "upper-case-first", "css-selector-tokenizer", "normalize-wheel", "socks", "stack-utils", "promise", "browser-process-hrtime", "nodegit-promise", "bson", "buffer-to-arraybuffer", "is-buffer", "date-now", "mississippi", "yaeti", "ev-store", "scrypt-js", "viewport-dimensions", "grunt-contrib-uglify", "is-dotfile", "lodash._root", "just-curry-it", "ndarray", "require-from-string", "echarts", "uncontrollable", "progress-bar-webpack-plugin", "pkg-dir", "jest-snapshot", "base-x", "lodash.partialright", "is-accessor-descriptor", "sshpk", "lodash.escaperegexp", "yeoman-generator", "glob-to-regexp", "postcss-discard-comments", "oauth", "rxjs-compat", "flatmap-stream", "he", "to-space-case", "temp", "sw-precache", "sync-request", "postcss-merge-longhand", "semver-compare", "brace-expansion", "uglifyjs-webpack-plugin", "sass-graph", "ext-name", "es6-iterator", "timespan", "domino", "arraybuffer.slice", "amdefine", "glob-base", "postcss-sass", "simple-git", "ini", "babel-plugin-transform-es2015-classes", "lodash.includes", "is-word-character", "dom-scroll-into-view", "config-chain", "clean-webpack-plugin", "pseudomap", "p-defer", "boom", "babel-core", "workbox-sw", "rc-notification", "stream-splicer", "lodash.pad", "less-loader", "ecstatic", "metro-memory-fs", "promirepl", "detect-file", "canvas", "varuint-bitcoin", "chance", "taketalk", "babel-plugin-ember-modules-api-polyfill", "rimraf", "squeak", "readline", "ethjs-util", "esprima", "karma-phantomjs-launcher", "cliff", "socket.io-client", "node-libs-browser", "istanbul-lib-report", "i18next", "node.extend", "dnd-core", "builtin-status-codes", "file-type", "array-map", "is-absolute", "is-redirect"]);
exports.ignoredNodeModules = ignoredNodeModules;
//# sourceMappingURL=IgnoredNodeModules.js.map